@@ -285,10 +285,8 @@ function(x, breaks, labels, start.on.monday = TRUE) {
                    days = from,
                    weeks = (from - day.of.week(mdy$m, mdy$d, mdy$y)
                             + as.numeric(start.on.monday)),
-                   months = chron(paste(mdy$month, "01", mdy$year -
-                   1900, sep = "/"), format = "m/d/y", origin = orig),
-                   years = chron(paste("01", "01", mdy$year - 1900,
-                   sep = "/"), format = "m/d/y", origin = orig))
+                   months = chron(julian(mdy$m, 1, mdy$y, origin = orig)),
+                   years = chron(julian(1, 1, mdy$y, origin = orig)))
     if(from == min(x))
         from <- from - .Machine$double.eps
     breaks <- brk <- seq(from = from, to = max(x) + bump, by = by)
